@@ -9,6 +9,8 @@ from django.contrib.admin.templatetags.admin_urls import admin_urlname
 from .models import ClientHistory
 from .models import Clients
 from .models import Visits
+from .models import Newsletter
+from .models import NewsletterLink
 
 
 class HistoryInline(admin.TabularInline):
@@ -19,9 +21,28 @@ class HistoryInline(admin.TabularInline):
     extra = 1
 
 
+class NewsletterLinksInline(admin.TabularInline):
+    fieldsets = [
+        (None, {'fields': ['link']}),
+    ]
+    model = NewsletterLink
+    extra = 1
+
+
 class ClientsAdmin(admin.ModelAdmin):
+
+    if 'SHOW_EMAILS' in os.environ:
+        show_email = os.environ['SHOW_EMAILS']
+    else:
+        show_email = True
+
+    if show_email == True:
+        field = 'email'
+    else:
+        field = 'name'
+
     list_display = (
-        'email',
+        field,
         'company',
         'org_number',
         'phone',
@@ -32,7 +53,8 @@ class ClientsAdmin(admin.ModelAdmin):
         'all_visits',
         'last_visit'
     )
-    search_fields = ('email', 'name', 'company', 'org_number', 'phone',)
+
+    search_fields = (field, 'company', 'org_number', 'phone',)
     readonly_fields = ('last_7_days_visits', 'last_30_days_visits', 'all_visits')
     inlines = [HistoryInline]
     ordering = [F('last_visit').desc(nulls_last=True)]
@@ -42,9 +64,8 @@ class ClientsAdmin(admin.ModelAdmin):
             'classes': ('',),
             'fields': (
                 'active',
-                'email',
+                field,
                 'selected_client',
-                'name',
                 'company',
                 'position',
                 'org_number',
@@ -58,7 +79,7 @@ class ClientsAdmin(admin.ModelAdmin):
 
     def get_queryset(self, request):
         qs = super(ClientsAdmin, self).get_queryset(request)
-        return qs.filter(last_30_days_visits__gte=os.environ['FILTER_NUMBER_OF_VISITS_30_DAYS'])
+        return qs.filter(last_30_days_visits__gte=os.environ['FILTER_NUMBER_OF_VISITS_30_DAYS']).filter(bot=0)
 
     def change_view(self, request, object_id, form_url='', extra_context=None):
         extra_context = extra_context or {}
@@ -101,5 +122,10 @@ class VisitsAdmin(admin.ModelAdmin):
     find_person_other.short_description = 'Kund'
 
 
+class NewsletterAdmin(admin.ModelAdmin):
+    inlines = [NewsletterLinksInline]
+
+
 admin.site.register(Visits, VisitsAdmin)
 admin.site.register(Clients, ClientsAdmin)
+admin.site.register(Newsletter, NewsletterAdmin)
