@@ -59,7 +59,7 @@ class Command(BaseCommand):
             exit(0)
 
         with open(filename, 'r') as cv:
-            data = csv.reader(cv, delimiter=',')
+            data = csv.reader(cv, delimiter=';')
             wrong_pad = []
             value_error = []
             for item in data:
