@@ -2,6 +2,7 @@ import pytz
 import os
 import csv
 import psycopg2
+from icecream import ic
 from pymongo import MongoClient  # type: ignore
 from datetime import datetime, timedelta
 from urllib.parse import urlparse
@@ -52,6 +53,10 @@ def agg_last_30_days_visits(uid, domain_id):
     return agg_last_visits(uid, 30, domain_id=domain_id)
 
 
+def agg_all_visits(uid, domain_id):
+    return Visits.objects.filter(uid=uid).count()
+
+
 def last_user_visit(uid):
     """
     TODO
@@ -182,6 +187,9 @@ class Command(BaseCommand):
         """
         Take all trakcings
         """
+        ic(start_date)
+        ic(now)
+        ic(domain_id)
 
         cursor_agg_impressions = collection_impressions_agg.find({'domain_id': domain_id, 'createdAt': {
             '$gte': start_date,
@@ -203,6 +211,11 @@ class Command(BaseCommand):
             todo: not save if uid is empty
             """
             if Clients.objects.filter(uid=uid).count():
+                if len(post['url']) > 255:
+                    post['url'] = post['url'][:255]
+
+                ic(post['url'])
+
                 visits = Visits(uid=uid, url=post['url'], created_at=aware_date)
                 visits.save()
             else:
@@ -224,12 +237,13 @@ class Command(BaseCommand):
                 """
                 last_7_days = agg_last_7_days_visits(uid, domain_id=domain_id)
                 last_30_days = agg_last_30_days_visits(uid, domain_id=domain_id)
+                all_visits = agg_all_visits(uid, domain_id=domain_id)
 
                 """
                 Update user data
                 """
                 find_client_by_uid = Clients.objects.filter(uid=uid).get()
-                find_client_by_uid.all_visits = find_client_by_uid.all_visits + 1
+                find_client_by_uid.all_visits = all_visits
                 find_client_by_uid.last_visit = aware_date
                 find_client_by_uid.last_7_days_visits = last_7_days
                 find_client_by_uid.last_30_days_visits = last_30_days
